@@ -24,7 +24,7 @@ class EnviarPedido(Enviar):
         self.exige_autenticacao = True
         self.processa_resposta = True
         self.url = "https://api-3t.{}paypal.com/nvp".format(self.sandbox)
-        self.grava_identificador = False
+        self.grava_identificador = True
         self.headers = {"Content-Type": "application/x-www-form-urlencoded; charset=utf-8"}
         self.formato_de_envio = FormatoDeEnvio.form_urlencode
 
@@ -77,10 +77,6 @@ class EnviarPedido(Enviar):
         nome = "L_PAYMENTREQUEST_0_{}{}".format(atributo, indice)
         express_checkout.define_valor_de_atributo(nome, {nome.lower(): valor})
 
-    @property
-    def items(self):
-        return []
-
     def obter_situacao_do_pedido(self, status_requisicao):
         return None
 
@@ -91,8 +87,9 @@ class EnviarPedido(Enviar):
             content = urllib.unquote(content).decode('utf8')
             retorno = {par.split("=")[0].lower(): par.split("=")[1].lower() for par in content.split("&")}
         if "ack" in retorno and retorno["ack"] == TipoAck.Sucesso:
-            url = "https://www.{}paypal.com/cgi-bin/webscr?cmd=_express-checkout&token={}".format(self.sandbox, retorno["token"])
-            return {"content": {"url": url}, "status": 200, "reenviar": False, "identificador": retorno["token"]}
+            token = retorno["token"].upper()
+            url = "https://www.{}paypal.com/cgi-bin/webscr?cmd=_express-checkout&token={}".format(self.sandbox, token)
+            return {"content": {"url": url}, "status": 200, "reenviar": False, "identificador": token}
 
         return {"content": retorno, "status": 500, "reenviar": False}
 
