@@ -101,7 +101,9 @@ class Registro(RegistroBase):
 
     @property
     def obter_dados_do_gateway(self):
-        return self.retorno_de_requisicao
+        if self.retorno_de_requisicao:
+            return self.tipo in ["success", "pending"]
+        return True
 
     @property
     def redireciona_para(self):
@@ -120,7 +122,7 @@ class Registro(RegistroBase):
             retorno = {par.split("=")[0].lower(): par.split("=")[1].lower() for par in content.split("&")}
         ack = AckRetorno(retorno["ack"])
         self.sucesso = ack.sucesso
-        if retorno["paymentinfo_0_paymentstatus"].lower() == SituacoesDePagamento.do_tipo("pendente"):
+        if "paymentinfo_0_paymentstatus" in retorno and retorno["paymentinfo_0_paymentstatus"].lower() == SituacoesDePagamento.do_tipo("pendente"):
             self.tipo = "pending"
         return {"content": retorno, "status": 200 if self.sucesso else 500, "reenviar": False}
 
@@ -151,7 +153,7 @@ class Registro(RegistroBase):
             version=settings.PAYPAL_VERSION,
             method='DoExpressCheckoutPayment',
             token=self.dados["token"],
-            payerid=self.dados["payerid"],
+            payerid=self.dados["PayerID"],
 
             paymentrequest_0_paymentaction='SALE',
             paymentrequest_0_notifyurl=notification_url,
